@@ -4,7 +4,7 @@ use std::path::PathBuf;
 
 #[inline(always)]
 pub(crate) fn gen_snapshot(cfg: &BtmCfg, idx: u64) -> Result<()> {
-    alt!(0 != idx % cfg.itv as u64, return Ok(()));
+    alt!(0 != (u64::MAX - idx) % cfg.itv as u64, return Ok(()));
     clean_outdated(cfg).c(d!())?;
     let cmd = format!(
         "
@@ -152,7 +152,7 @@ fn clean_outdated_fade(cfg: &BtmCfg) -> Result<()> {
         };
 
         pair.0.iter().for_each(|n| {
-            if 0 != n % denominator as u64 {
+            if 0 != (u64::MAX - n) % denominator as u64 {
                 to_del.push(format!("{}@{}", &cfg.target, n));
             }
         });
